@@ -151,22 +151,27 @@ class Workflow(CacheableBase):
         if not response['result']:
             return jobStatsPerTask
 
-        for agentName, agentData in response['result'][0].get(self.workflowName)['AgentJobInfo'].items():
-            for taskName, taskData in agentData['tasks'].items():
-                # Some tasks such as LogCollect, Cleanup etc. don't have job info
-                # TODO: Decide whether we should ignore such tasks or not. Ignore for now
-                if 'status' not in  taskData:
-                    continue
-                else:
-                    taskStatus = taskData['status']
-                nSuccess = taskStatus['success'] if 'success' in taskStatus else 0
-                nFailure = sum(taskStatus['failure'].values()) if 'failure' in taskStatus else 0
-                if taskName in jobStatsPerTask:
-                    jobStatsPerTask[taskName]['nSuccess'] += nSuccess
-                    jobStatsPerTask[taskName]['nFailure'] += nFailure
-                else:
-                    jobStatsPerTask[taskName] = {'nSuccess': nSuccess, 'nFailure': nFailure} 
-        return jobStatsPerTask
+        try:
+            for agentName, agentData in response['result'][0].get(self.workflowName)['AgentJobInfo'].items():
+                for taskName, taskData in agentData['tasks'].items():
+                    # Some tasks such as LogCollect, Cleanup etc. don't have job info
+                    # TODO: Decide whether we should ignore such tasks or not. Ignore for now
+                    if 'status' not in  taskData:
+                        continue
+                    else:
+                        taskStatus = taskData['status']
+                    nSuccess = taskStatus['success'] if 'success' in taskStatus else 0
+                    nFailure = sum(taskStatus['failure'].values()) if 'failure' in taskStatus else 0
+                    if taskName in jobStatsPerTask:
+                        jobStatsPerTask[taskName]['nSuccess'] += nSuccess
+                        jobStatsPerTask[taskName]['nFailure'] += nFailure
+                    else:
+                        jobStatsPerTask[taskName] = {'nSuccess': nSuccess, 'nFailure': nFailure}
+            return jobStatsPerTask
+        except Exception as e:
+            print(str(e))
+            return {}
+
 
     def getFailureRate(self):
         """
@@ -177,13 +182,17 @@ class Workflow(CacheableBase):
         """
         failureRatePerTask = {}
         jobStats = self.getJobStats()
-        for taskName, stats in jobStats.items():
-            # Avoid division by zero, although we shouldn't have such data
-            if stats['nFailure'] == 0 and stats['nSuccess'] == 0:
-                failureRatePerTask[taskName] = -1 
-            else:
-                failureRatePerTask[taskName] = stats['nFailure'] / (stats['nFailure'] + stats['nSuccess'])
-        return failureRatePerTask
+        try:
+            for taskName, stats in jobStats.items():
+                # Avoid division by zero, although we shouldn't have such data
+                if stats['nFailure'] == 0 and stats['nSuccess'] == 0:
+                    failureRatePerTask[taskName] = -1
+                else:
+                    failureRatePerTask[taskName] = stats['nFailure'] / (stats['nFailure'] + stats['nSuccess'])
+            return failureRatePerTask
+        except Exception as e:
+            print(str(e))
+            return {}
    
 
     ## Get request related values
